@@ -11,6 +11,11 @@ import crypto
 from futures import ThreadPoolExecutor
 
 from hlsclient.transcode import transcode_playlist
+from hlsclient import helpers
+
+config = helpers.load_config()
+NUM_THREAD_WORKERS = config.getint('hlsclient', 'num_thread_workers')
+DOWNLOAD_TIMEOUT = config.getint('hlsclient', 'download_timeout')
 
 def consume_from_balancer(balancer, playlists, destination, encrypt=False):
     '''
@@ -36,7 +41,7 @@ def consume_from_balancer(balancer, playlists, destination, encrypt=False):
                 transcode_playlist(playlists, playlist_resource.key, modified, m3u8_path)
             else:
                 logging.debug('Content not modified: %s' % m3u8_uri)
-    with ThreadPoolExecutor(max_workers=4) as executor:
+    with ThreadPoolExecutor(max_workers=NUM_THREAD_WORKERS) as executor:
         list(executor.map(consume_resource, balancer.actives))
 
 def consume(m3u8_uri, destination_path, encrypt=False):
@@ -114,7 +119,7 @@ def download_segments(playlist, destination_path, new_key):
     uris = [segment.absolute_uri for segment in playlist.segments]
     def download(uri):
         return download_to_file(uri, destination_path, playlist.key, new_key)
-    with ThreadPoolExecutor(max_workers=4) as executor:
+    with ThreadPoolExecutor(max_workers=NUM_THREAD_WORKERS) as executor:
         downloads = executor.map(download, uris)
         return list(downloads)
 
@@ -153,7 +158,7 @@ def download_to_file(uri, destination_path, current_key=None, new_key=False):
     filename = os.path.join(destination_path, os.path.basename(uri))
     if not os.path.exists(filename):
         logging.debug("Downloading {url}".format(url=uri))
-        raw = urllib2.urlopen(url=uri, timeout=30)
+        raw = urllib2.urlopen(url=uri, timeout=DOWNLOAD_TIMEOUT)
         if new_key is not False:
             plain = crypto.Decrypt(raw, current_key) if current_key else raw
             raw = crypto.Encrypt(plain, new_key) if new_key else plain
